package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut

__DATA__

M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````^`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````")82,1D3J
MWT9$ZM]&1.K?Q5CDWT1$ZM\I6^#?343JWRE;[M]$1.K?Q4RWWT)$ZM\]6.;?
M1$3JWT9$Z]\61.K?N63NWT5$ZM]P8N#?1$3JW_Y"[-]'1.K?4FEC:$9$ZM\`
M``````````````````````````````!010``3`$$`/'+MT8``````````.``
M#P$+`08``#````"0````````\#D````0````0`````!````0````$```!```
M```````$``````````#0````$```9DX!``,``````!```!``````$```$```
M`````!```````````````-24``!D`````+```-`1````````````````````
M```````````````P00``'```````````````````````````````````````
M````````````````````0```)`$`````````````````````````````````
M`"YT97AT````+"L````0````,````!```````````````````"```&`N<F1A
M=&$``*Y:````0````&````!```````````````````!```!`+F1A=&$```!D
M!````*`````0````H```````````````````0```P"YR<W)C````T!$```"P
M````(````+```````````````````$```,``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&AP04``:`0Y0`!H5$%``.CJ*```4.C>*```@\00PS/`PU6+[('L"`0``%-6
M5VB804``Z*@!``")1?R-A?C[___'!"0`!```,]M04_\5"$!``(7`#X5,`0``
M_S40H$``BW4(5O\5A$!``%E9A<!6=!-HB$%``.CS`0``68O&6>E7`0``Z!XI
M``#_-12@0`"+/8Q`0`")1?C_=0S_UX/$#(OP._,/A!\!```X'G4%OH1!0``Y
M7?QT$U;_=?SHX"@``%F%P%D/A,L```!6Z-8H``"*5##_68L-$*!``#H1=0I(
MB!P&BE0&_^OLBU7X_W4(C400`3T`!```#XW-````45:-A?C[__]H?$%``%#_
M%91`0`#HYR<``%#H\R<``(LPZ-HG``!0Z.`G``"#Q!Q0C87X^___4.C$)P``
M4.C0)P``6?\P_U90@\0,A<!U2.BL)P``4.BR)P``9HM`!EEF)0#P9CT`@'4N
MZ)(G``!0Z)XG``"+,%F-A?C[__]J`5#H>R<``%#HAR<``%G_,/\6@\0,A<!T
M$/\U%*!``%/_UUE9Z?K^__^-A?C[__]0:(A!0`#HMP```(V%^/O__U#_%41`
M0`"#Q`SK$O]U"&B(04``Z)@```"+10A965]>6\G#58OLC44(4/]U".@$````
M65E=PU6+[%%35HMU"%>%]G1FBQV`0$``_].#.`!T68H.B\:$R70+@/D]=`:*
M2`%`Z_$KQHE%_/_3BS"+/H7_=#?_=?S_=0A7_Q5`0$``@\0,A<!U"8M%_(`\
M!SUT!8/&!.O8_],K,(M%#,'^`HDPBT7\C40'`>L",\!?7EO)PU6+[%%1BT4,
M@#@]=0/_10Q35E?_=0SH'B<``(M="(E%^(U%_%!3Z%K___^+-8!`0`"+^(/$
M#(7_=")7Z/DF```[1?A9#X++````BTT,B@&(!T=!A,!U]ND\`0``_]:+`#/_
M,\DY"'0&@\`$1^OV.0U$I$``=$#H%B8``%#H*"8``(L868T$O0@```!0_];_
M,.C\)0``4.@.)@``6?\P_U,$@\0,B]C_UHD8_]:#.`!U5>FQ````QP5$I$``
M`0```.C,)0``4.C>)0``BQA9C02]"````%#HMB4``%#HR"4``%G_,/\3B]A9
MA=M9='F+Q\'@`E#_UO\P4_\5?$!``(/$#/_6B1C_UHL`BUT(@V2X!`")??R*
M`XO[A,!T"CP]=`:*1P%'Z_+H924``%#H=R4``(L0BT7X*_M9B54(C40'`E#H
M2B4``%#H7"4``%G_,(M%"/\068OX6?_6BP"+3?R%_XD\B'4%@\C_ZR[_UHL`
MBTW\BP2(B@M#A,F("'0(@/D]=`-`Z^^+50S&`#U`B@J("$!"A,EU]C/`7UY;
MR<.+1"0$5HOPB\B*`(3`=!>+%1"@0`"*$CK"=0.-<0&*00%!A,!U\8O&7L-6
MBW0D"(7V=&^`/@!T:E;H7"4``(U$,/]9BPT0H$``.\9V%HH1.!!U!4@[QG?W
M.\9V"3@0=`-(Z_4[QG4)B@`Z`70U4>LW2#O&=@:*$#H1=/4KQHU(`H'Y``0`
M`'8$,\!>PT!05KX\H$``5O\5>$!``(/$#(O&7L-HA$%``/\51$!``%E>PU6+
M[(/L)%-65VH(6;YL0D``C7W<:%Q"0`#SI6:EZ`D!``#'!"100D``Z/T```"[
MF$%``%/H\@```+Y$0D``5NCG````OSA"0`!7Z-P```!H+$)``.C2````:(A!
M0`#HR````&@@0D``Z+X```!H%$)``.BT````:`!"0`#HHOS__X/$)(7`=`E0
M5^@B_?__65EH[$%``.B(_/__A<!9=`U0:.!!0`#H!OW__UE9:-!!0`#H;/S_
M_X7`670+4%/H[OS__UE9ZTYHO$%``.A2_/__A<!9=`105NOD:+1!0`#H!B0`
M`+^H04``C5P%Z%?H]R,``%!74_\5=$!``(/$%(7`=1)7Z.$C```#PU!6Z)_\
M__^#Q`QHI$%``&A<0D``Z(W\__]965]>6\G#58OL48U%_%#_=0CH^_O__UF%
MP%ET'O\5@$!``(L`BTW\C0R(BU$$C4$$A=*)$734B\CK\,G#H1B@0`"#^/]U
M)6A$0D``Z*[[__^%P%ET#XH`A,!T"3PP=`5J`5CK`C/`HQB@0`##58OL@^P@
MN,A"0`!7B_A0B47@QT7DP$)``,=%Z+!"0`#'1>RH0D``QT7PE$)``,=%])!"
M0`")??CH'",``(7`60^&Q````(U%X%-6B47\5^@^^___B_!9A?8/A(,```!6
MZ/0B``"%P%ET>/]U"%;_%81`0`!9A<!9=7/H,B(``%#H1"(``/\U%*!``(LX
MZ,<B``!6B]CHOR(``/]U"`/8Z+4B``"#Q!"-1`,"4.@`(@``4.@2(@``6?\P
M_Q=6B_C_-12@0`#_=0AH?$%``%?_%91`0`!7_W7XZ$/[__^#Q"3K"_]U"%?H
M-?O__UE9@T7\!(M%_(LX5XE]^.A:(@``A<!9#X=&____7EM?R<-5B^RXX(``
M`.A)(@``@V7T`%-6NY!"0`!HF$%``,=%V%1#0`#'1=Q,0T``QT7@A$%``(E=
MY,=%P.!!0`#'1<1$0T``QT7(/$-``,=%S#1#0`#'1=`P0T``B5W4QT7H*$-`
M`,=%[!Q#0`")7?#H%/K__XOP687V=!]6Z,XA``"%P%ET%%;H:O[__U;_%41`
M0`!96>ER!0``O@`$``!7B77XZ/\@``!0Z!$A``"+.%E6Z/`@``!0Z`(A``!9
M_S#_%UE9C4WX45#_%0!`0`#H\_?__X7`B47X=3Z-?>B+-U;H:2$``(7`678?
M5NB7^?__A<!9=`M0_Q5$0$``68E%^(/'!(-]^`!TU(-]^`!U"<=%^!1#0`#K
M1(MU^(`^`'0\OP<!``"A9$!``(,X`7X/#[X&5U#_%6A`0`!96>L1BPUL0$``
M#[X&BPEFBP1!(\>%P'4#Q@9?1H`^`'7)C47`B47\BT7\BS!6Z.$@``"%P%D/
MAJ````!6Z`OY__^+\%F%]@^$@0```.@:(```4.@F(```BSCH#2```%#H$R``
M`%E94%;H_A\``%#H"B```%G_,/]74(/$#(7`=4WHYA\``%#H[!\``&:+0`99
M9B4`\&8]`$!U,^C,'P``4.C8'P``BSA9:@)6Z+L?``!0Z,<?``!9_S#_%X/$
M#(7`=0M6_Q5$0$``68E%](-%_`2#??0`#X1,____@WWT``^%J0```(U%V(E%
M_(M%_(LP5N@=(```A<!9#X:/````Z&<?``!0Z',?``"+..A:'P``4.A@'P``
M65E05NA+'P``4.A7'P``6?\P_U=0@\0,A<!U3>@S'P``4.@Y'P``9HM`!EEF
M)0#P9CT`0'4SZ!D?``!0Z"4?``"+.%EJ`E;H"!\``%#H%!\``%G_,/\7@\0,
MA<!U"U;_%41`0`!9B47T@T7\!(-]]``/A%W_____=?CH?1\``/]U](OXZ',?
M``"^#$-```/X5NAF'P``4P/XZ%X?``"-O`<`!```Z*H>``!0Z+P>``"+$(/$
M%(E5_%?HEAX``%#HJ!X``%G_,(M%_/\0_W7XB47\5HLUE$!``/\U$*!``/]U
M]&@`0T``4/_6_W7\_Q5P0$``:*A"0`#H./?__U#_%41`0`"+?0A0_S?H:/7_
M_X/$-(E%"(7`=06+!XE%".A0^___A<`/A2D"``#H)!X``%#H,!X``(LXQP0D
M`(```/]U".@-'@``4.@9'@``6?\P_U<\@\0,B44(A<`/A/,!``#H[AT``%#H
M^AT``%F+.&H":O]J[O]U".C7'0``4.CC'0``6?\P_U<PZ,8=``!0Z-(=``"+
M.(/$&(V%('___VH&4/]U".BJ'0``4.BV'0``6?\P_U=$@\00@+T@?___``^%
MM0```("](7___T,/A:@```"`O2)___]!#X6;````@+TC?___0P^%C@```("]
M)'___T@/A8$```"`O25___]%=7CH3!T``%#H6!T``%F+.&H":O]JQO]U".@U
M'0``4.A!'0``6?\P_U<PZ"0=``!0Z#`=``"+.(/$&(V%('___VHI4/]U".@(
M'0``4.@4'0``6?\P_U=$C84@?___4U#_-1"@0`#_=?QH\$)``/]U_/_6@\0H
MZ2(!``"-A2#___]0Z#8!``#HR!P``%#HU!P``%E9BSB-A2!___]H`(```%#_
M=0CHJAP``%#HMAP``%G_,/]71(/$$(7`?B10C84@?___4(V%(/___U#H'@$`
M`.A^'```4.B*'```@\00Z[/H;AP``%#H>AP``(LX6?]U".A='```4.AI'```
M6?\P_U<0C84@____4(U%K%#HNQ,``(U%@(/$$#/_B44(#[9$/:Q0:.A"0`#_
M=0C_UH-%"`*#Q`Q'@_\4?..-18!3@&6H`%#_-1"@0`#_=?QH\$)``.M!:*1!
M0`!H1$)``.A@]?__65E3Z.D;``!0Z`$<``"+..C<&P``4.CT&P``_S#_5VB#
MQ`Q0_S40H$``_W7\:-A"0`#_=?S_UH/$&/]U_&B804``Z!GU____=?SH\?C_
M_XM%_(/$#%]>6\G#BT0D!#/)QP`!(T5GQT`$B:O-[\=`"/[<NIC'0`QV5#(0
MQT`0\.'2PXE(%(E(&(E(7,-5B^Q3BUT05HMU"%>+3A2-!-D[P7,#_T88B484
MB\/!Z!T!1AB+1ER%P'0T:D!?*_@[^WX"B_N+1EQ7_W4,C40&'%#H`!P```%]
M#`%^7(/$#"O?@WY<0'5+5NA*````68/[0'PLB_O![P:+Q_?8P>`&`]AJ0(U&
M'/]U#%#HQQL``(-%#$!6Z!X```"#Q!!/=>)3C48<_W4,4.BJ&P``@\0,B5Y<
M7UY;7<-5B^R![%0!``"+10A35E>-4!R-M:S^___'10@0````BPJ#P@2+^8O9
M@><``/\`P>L0"_N+V8'C`/\``,'A$`O9P>\(P>,("_N)/H/&!/]-"'7-:D"-
ME;3^__]>BTHL,TH8,TKX,PJ#P@2+^0/)P>\?"_E.B7HT=>.+>`2+4`B+<`R+
M"(O?(]?WTR/>B_$+VHO1P>H;P>8%"]:+<!`#\P/6B[6L_O__C90RF7F"6HOW
MP>8>P>\""_>+^??7(W@(B77L(_&+V@O^B_+!ZQO!Y@4+WHNUL/[__P/W`]Z+
M<`R-O#.9>8):B_&+V8E]^,'F'L'K`@OSB]KWTR-=[(EU_"/R"]Z+M;3^__^)
M70B+W\'K&\'G!0O?BWT(`_>+^L'G'L'J`@/>BW`("_J+5?B-M#.9>8):BUWX
M]](C5?PCWXE]](O^"].+WL'O&\'C!0O[BYVX_O__`]H#^XM5[(V<%YEY@EJ+
M??B+UXE=",'B'L'O`@O7B_[WUR-]](E5^"/6"_J+T\'J&\'C!0O3BYV\_O__
M`]^+??P#TXV4.IEY@EJ+_L'G'L'N`@O^BW4(]]8C=?B)??`C?0B+VL'C!0OW
MB_K![QL+^XN=P/[__P/>BW7T`_N-G#>9>8):BWT(B_>)7?S!YA[![P(+]XOZ
M]]<C??")=0@C\@O^B_/![AO!XP4+\XN=Q/[__P/?BWWX`_.-M#Z9>8):B_K!
MYQ[!Z@(+^HM5_/?2(U4(B7WL(WW\B][!XP4+UXO^P>\;"_N+G<C^__\#VHM5
M\`/[C9P7F7F"6HM]_(O7B5WXP>(>P>\""]>+_O?7(WWLB57\(]8+^HO3P>H;
MP>,%"].+G<S^__\#WXM]"`/3BUWXC90ZF7F"6HO^P><>P>X""_Z+=?CWUB-U
M_"/?B7WTB_H+\XO:P>\;P>,%"_N+G=#^__\#WHMU[`/[C9PWF7F"6HM]^(OW
MB5T(P>8>P>\""_>+^O?7(WWTB77X(_(+_HOSP>X;P>,%"_.+G=3^__\#WXM]
M_`/SC;0^F7F"6HOZP><>P>H""_J+50CWTB-5^(E]\"-]"(O>P>,%"]>+_L'O
M&PO[BYW8_O__`]J+5?0#^XV<%YEY@EJ+?0B+UXE=_,'B'L'O`@O7B_[WUR-]
M\(E5""/6"_J+T\'J&\'C!0O3BYW<_O__`]^+??@#TXV4.IEY@EJ+_L'G'L'N
M`@O^BW7\]]8C=0B)?>PC??R+VL'C!0OWB_K![QL+^XN=X/[__P/>BW7P`_N-
MG#>9>8):BWW\B_>)7?C!YA[![P(+]XOZ]]<C?>R)=?PC\@O^B_/![AO!XP4+
M\XN=Y/[__P/?BWT(`_.+7?B-M#Z9>8):B_K!YQ[!Z@(+^HM5^/?2(U7\B7WT
M(]^+_@O3B][![QO!XP4+^XN=Z/[__P/:BU7L`_N-G!>9>8):BWWXB]>)70C!
MXA[![P(+UXO^]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=[/[__P/?BWW\`].-
ME#J9>8):B_[!YQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;"_N+
MG?#^__\#WHMU]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWPB74(
M(_(+_HOSP>X;P>,%"_.+G?3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H""_J+
M5?SWTB-5"(E]["-]_`O7B_[![QN+WL'C!0O[BYWX_O__`]J+5?`#^XV<%YEY
M@EJ+??R+UXE=^,'B'L'O`@O7B_O![QO!XP4+^XM=[(E5_#/:BY7\_O__,]X#
MUXO^`]J+50C!YQ[![@(+_HV4$Z'KV6Z)??2+\HOZBYT`____P>X;P><%"_>+
M??@S??P#WHMU[#-]]`/[C9PWH>O9;HM]^(OWB5T(P>8>P>\""_>+^\'O&\'C
M!8EU^`O[BYT$____,_(S=?0#WXM]_`/SC;0^H>O9;HOZP><>P>H""_J+UHO>
MB7WPP>H;P>,%"].+7?@SWXN]"/___S-="`/ZBU7T`]^-G!.AZ]ENBWT(B5W\
MB]?!XA[![P(+UXO[P>\;P>,%"_N+7?")50@SVHN5#/___S/>`]>+_@/:BU7X
MP><>P>X"C903H>O9;@O^B_*+VL'N&\'C!0OSBUT(B7WL,]^+O1#___\S7?P#
M_HMU\`/?BWW\C9PSH>O9;HOWP>8>P>\""_>+^XE=^(EU_,'O&\'C!0O[BUWL
M,]Z+M13___\SV@/WB_H#WHMU",'G'L'J`@OZC;0SH>O9;HE]](O6B_Z+G1C_
M___!ZAO!YP4+UXM]^#-]_`/:BU7L,WWT`_N-G!>AZ]ENBWWXB]>)70C!XA[!
M[P(+UXE5^(O[,]8S5?3![QO!XP4+^XN='/___P/?BWW\`].-E#JAZ]ENB_[!
MYQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?B[T@____,UT(`_Z+=?0#WXM]
M"(V<,Z'KV6Z+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=\#/>B[4D____
M,]H#]P/>BW7XB_K!YQ[!Z@*-M#.AZ]EN"_J+UHO>P>H;P>,%"].+70B)?>PS
MWXN]*/___S-=_`/ZBU7P`]^+??R-G!.AZ]ENB]?!XA[![P(+UXO[B5WXB57\
MP>\;P>,%"_N+7>PSVHN5+/___S/>`]>+_@/:BU4(P><>P>X""_Z-E!.AZ]EN
MB7WTB_*+^HN=,/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-Z'KV6Z+
M??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XN=-/___S/R,W7T`]^+??P#
M\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+O3C___\S
M70@#^HM5]`/?BWT(C9P3H>O9;HO7P>(>P>\""]>+^XE=_(E5",'O&\'C!0O[
MBUWP,]J+E3S___\SW@/7`]J+5?B-O!.AZ]ENB];!XA[![@(+UHOWB]_![AO!
MXP4+\XM="(E5[#/:BY5`____,UW\`]:+=?P#VHM5\(V<$Z'KV6Z+UL'B'L'N
M`@O6B_.)7?B)5?S![AO!XP4+\XM=[#/:BY5$____,]\#UHOW`]J+50C!YA[!
M[P(+]XV4$Z'KV6Z)=?2+\HOZBYU(____P>X;P><%"_>+??@S??P#WHMU[#-]
M]`/[C;0WH>O9;HM]^(EU"(OWP>8>P>\""_>+^@M]](M="(EU^"/^B_(C=?3!
MXP4+_HMU",'N&POSBYU,____`]^+??P#\XVT/MR\&X^+^L'G'L'J`@OZB]>)
M??`+50@C5?@C?0B+W@O7B_[![QO!XP4+^XN=4/___P/:BU7T`_N-G!?<O!N/
MBWT(B]>)7?S!XA[![P(+UXOZB54("_XCUB-]\`OZB]/!ZAO!XP4+TXN=5/__
M_P/?BWWX`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)?>P+=?PC??S!XP4C=0@+
M]XOZP>\;"_N+G5C___\#WHMU\`/[C9PWW+P;CXM]_(OWB5WXP>8>P>\""_>+
M_HEU_`OZ(_(C?>P+_HOSP>X;P>,%"_.+G5S___\#WXM]"`/SC;0^W+P;CXOZ
MP><>P>H""_J+5?R)??2+7?P+UR-5^"/?B_X+TXO>P>\;P>,%"_N+G6#___\#
MVHM5[`/[C907W+P;CXM]^(E5"(O7P>(>P>\""]>+_@M]](M="(E5^"/ZB]8C
M5?3!XP4+^HM5",'J&PO3BYUD____`]^+??P#TXV4.MR\&X^+_L'G'L'N`@O^
MB]J+]XE]\`MU""-]",'C!2-U^`OWB_K![QL+^XN=:/___P/>BW7T`_N-G#?<
MO!N/BWT(B_>)7?S!YA[![P(+]XO^B74("_HC\B-]\`O^B_/![AO!XP4+\XN=
M;/___P/?BWWX`_.-M#[<O!N/B_K!YQ[!Z@(+^HO>B]>)?>P+5?PC??S!XP4C
M50@+UXO^P>\;"_N+G7#___\#VHM5\`/[C9P7W+P;CXM]_(O7B5WXP>(>P>\"
M"]>+^HE5_`O^(]8C?>P+^HO3P>H;P>,%"].+G73___\#WXM]"`/3BUW\C90Z
MW+P;CXO^P><>P>X""_Z+=?P+]R/?(W7XB7WTB_H+\XO:P>\;P>,%"_N+G7C_
M__\#WHMU[`/[C;0WW+P;CXM]^(EU"(OWP>8>P>\""_>+^@M]](M="(EU^"/^
MB_(C=?3!XP4+_HMU",'N&POSBYU\____`]\#\XM]_(VT/MR\&X^+^L'G'L'J
M`@OZB]Z+UXE]\`M5""-]",'C!2-5^`O7B_[![QL+^XM=@`/:BU7T`_N-G!?<
MO!N/BWT(B]>)7?S!XA[![P(+UXOZB54("_XCUB-]\`OZB]/!ZAO!XP4+TXM=
MA`/?BWWX`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)?>P+=?PC??S!XP4C=0@+
M]XOZP>\;"_N+78@#WHMU\`/[C9PWW+P;CXM]_(OWB5WXP>8>P>\""_>+_HEU
M_`OZ(_(C?>P+_HOSP>X;P>,%"_.+78P#WXM]"`/SBUW\C;0^W+P;CXOZP><>
MP>H""_J+5?P+UR/?(U7XB7WTB_X+TXO>P>\;P>,%"_N+79`#VHM5[`/[C907
MW+P;CXM]^(E5"(O7P>(>P>\""]>+_@M]](M="(E5^"/ZB]8C5?3!XP4+^HM5
M",'J&PO3BUV4`]^+??P#TXV4.MR\&X^+_L'G'L'N`@O^B]J+]XE]\`MU""-]
M",'C!2-U^`OWB_K![QL+^XM=F`/>BW7T`_N-G#?<O!N/BWT(B_>)7?S!YA[!
M[P(+]XO[P>\;P>,%"_N+7?`SWHEU"#/:BW6<`_>+^@/>BW7XP><>P>H"C;0S
MUL%BR@OZB]:+WL'J&\'C!0O3BUT(,]^)?>R+?:`S7?P#^HM5\`/?BWW\C9P3
MUL%BRHO7P>(>P>\""]>+^XE=^(E5_,'O&\'C!0O[BUWL,]J+5:0SW@/7B_X#
MVHM5",'G'L'N`@O^C903UL%BRHE]](ORB_J+7:C![AO!YP4+]XM]^#-]_`/>
MBW7L,WWT`_N-G#?6P6+*BWWXB_>)70C!YA[![P(+]XO[P>\;P>,%B77X"_N+
M7:PS\C-U]`/?BWW\`_.-M#[6P6+*B_K!YQ[!Z@(+^HO6B]Z)??#!ZAO!XP4+
MTXM=^#/?BWVP,UT(`_J+5?0#WXM]"(V<$];!8LJ+U\'B'L'O`@O7B_N)7?R)
M50C![QO!XP4+^XM=\#/:BU6T,]X#UP/:BU7XB_[!YQ[![@*-E!/6P6+*"_Z+
M\HO:P>X;P>,%"_.+70B)?>PSWXM]N#-=_`/^BW7P`]^+??R-G#/6P6+*B_?!
MYA[![P(+]XO[B5WXB77\P>\;P>,%"_N+7>PSWHMUO#/:`_>+^@/>BW4(P><>
MP>H""_J-M#/6P6+*B7WTB]:+_L'J&\'G!0O7BWWXBUW`,WW\`]J+5>PS??0#
M^XV<%];!8LJ+??B+UXE=",'B'L'O`@O7B_O![QO!XP6)5?@+^XM=Q#/6,U7T
M`]^+??P#TXV4.M;!8LJ+_L'G'L'N`@O^B_*+VHE]\,'N&\'C!0OSBUWX,]^+
M?<@S70@#_HMU]`/?BWT(C9PSUL%BRHOWP>8>P>\""_>+^XE=_(EU",'O&\'C
M!0O[BUWP,]Z+=<PSV@/W`]Z+=?B+^L'G'L'J`HVT,];!8LH+^HO6B][!ZAO!
MXP4+TXM="(E][#/?BWW0,UW\`_J+5?`#WXV<$];!8LJ+??R)7?B+U\'B'L'O
M`@O7B_O![QO!XP4+^XM=[(E5_#/:BU74,]X#UXO^`]J+50C!YQ[![@(+_HV4
M$];!8LJ)??2+\HOZBUW8P>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWUL%B
MRHM]^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUW<,_(S=?0#WXM]_`/S
MC;0^UL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXM]X#-="`/Z
MBU7T`]^+?0B-G!/6P6+*B]?!XA[![P(+UXE=_(E5"(O[P>\;P>,%"_N+7?`S
MVHM5Y#/>`]<#VHM5^(O^P><>P>X"C903UL%BRHM="`O^B_*)5?0SW\'N&\'B
M!0ORBU7\,]H#S@/9BTWP`UWHBW7TC8P+UL%BRHD(BT@$`\Z)2`2+RL'A'L'J
M`@O*BU4(`T@(B4@(BT@,`\]?B4@,BT@0`\I>B4@06\G#58OL4U:+=0R+1AB+
M7A2)10R+P\'H`X/@/\9$,!R`0(/X.'XJ:D!9*\B-1#`<46H`4.@X"0``5NB-
M[?__:CB-1AQJ`%#H)0D``(/$'.L5:CA9*\B-1#`<46H`4.@."0``@\0,BT4,
M5HO(B$97P>D8B$Y4B\C!Z1"(3E6+R(O#_W4(P>@8B$98B\/!Z!"(1EF+P\'I
M",'H"(A.5HA&6HA>6^@&````65E>6UW#5HMT)`Q6Z!/M__^+1"0,68L.P>D8
MB`B+#L'I$(A(`8L.P>D(B$@"B@Z(2`.+5@2-3@3!ZAB(4`2+$<'J$(A0!8L1
MP>H(B%`&B@F(2`>+5@B-3@C!ZAB(4`B+$<'J$(A0"8L1P>H(B%`*B@F(2`N+
M5@R-3@S!ZAB(4`R+$<'J$(A0#8L1P>H(B%`.B@F(2`^+5A"-3A!>P>H8B%`0
MBQ'!ZA"(4!&+$<'J"(A0$HH)B$@3PX'L)`$``%.+G"0L`0``5E>%VP^$,0(`
M`%/HLP<``(7`60^$(@(``%/HI`<``(OP@<8"`0``Z.\&``!0Z`$'``"+.%E9
M5NC?!@``4.CQ!@``6?\P_Q>+/91`0`"+\%-H<$-``%;_UXU$)"Q05O\52$!`
M`(/$'(/X_XE$)!0/A,<!``!5BRV$0$``C40D,&A004``4/_5687`68U$)#!0
M=0Y3:&A#0`!6_]>#Q!#K"VAD0T``5O_7@\0,NV!#0`!35O_5B_A9A?]9=!Y3
M5^CZ!@``687`670L:%Q#0`!7Z.D&``!9A<!9=!OV1"0<$'1<@[PD/`$```!T
M4FH!5NC__O__65F-1"0<4/]T)!S_%4Q`0`!9A<!9#X43`0``C40D,&A004``
M4/_5687`68U$)#!0=5O_M"0\`0``:&A#0`!6_Q640$``@\00ZU*-1"0P4/\5
M$$!``(-D)!``BSU00$``B40D%%;_UX7`6726BT0D$/]$)!"#^`I]B8-\)!0`
M=`K_="04_Q4,0$``5NO8:&1#0`!6_Q640$``@\0,4U;_U8OX687_670F4U?H
M&P8``%F%P%D/A$G___]H7$-``%?H!@8``%F%P%D/A#3____V1"0<$'0.@[PD
M/`$````/A17___^-1"0P4/\5$$!``(-D)!``BSU00$``B40D%%;_UX7`60^$
M^?[__XM$)!#_1"00@_@*#XWH_O__@WPD%`!T"O]T)!3_%0Q`0`!6Z]#_="08
M_Q540$``_[0D/`$``/\5H$!``%E975]>6X'$)`$``,-35HMT)`Q75N@!X/__
MB_A7Z,_?__]9B]A9Z-?A__^%P'0TA?9T,%;H4@4``(7`670E:`Q#0`!3_Q6$
M0$``63O#6743:@%6Z&+]__]J`%?H6OW__X/$$%]>6\-1@V0D``!35E?H;@0`
M`%#HP@0``&H!6X@8QP0D7$)``.@XW?__A<!9=`N`.#%U!H!X`0!T!>@`X/__
M:@I3:-Q#0`#H-00``%#H@P0``(/$$(7`#X2B````BP`Y'3RD0`!5B_.+0""+
M>!!^8[T```0`C4;_:@!05^@`!```4.A(!```@\00A<!T18L`BT@((\T[S74&
MBP"+`.L3:@)J`%#HV`,``%#H&@0``(/$$%"A0*1``/\TL.AC!```687`674-
M_T0D$$8[-3RD0`!\HJ$\I$``78U(_SE,)`QU'3O#B_-^%U?HDP,``%#HSP,`
M`$99.S4\I$``67SI:@13:-A#0`#H=0,``%#HPP,``(OP@\00A?9T-8L&:,Q#
M0`"+0"#_,.A5`P``4.B+`P``BP:#Q`R+0""+`/9`"4!T#E#H.0,``%#H:0,`
M`%E9:@13:,A#0`#H)`,``%#H<@,``(OP@\00A?9T<FB(04``Z.S;__^%P%ET
M`U#K2^@>VO__B_B%_W0YBP97BT`@_S#HZP(``%#H(0,``.C@`@``4.CR`@``
MBS"#Q!!7Z,\"``!0Z.$"``!9_S#_5@A96>L<H4"D0`#_,(L&BT`@_S#HK`(`
M`%#HX@(``(/$#.B>`@``4.CR`@``@"``Z)`"``!0Z+H"``"#(`!HF$%``.A>
MV___@\0,HSB@0`"%P'41_S5`I$``Z,+@__]9HSB@0`#H6P(``%#H?P(``(LP
MQP0D[0$``/\U.*!``.A!`@``4.AE`@``6?\P_Q:#Q`R%P%]>6W0E@_@1=""#
M^/]T&U"A0*1``/\U.*!``/\P:'A#0`#H+@(``(/$$%G#58OL45%6C44,5U"-
M10A0_Q6L0$``,_]7Z'X"``"#Q`R`.`!U2^AK`@``.\>C-*!``'4CZ,T!``!0
MZ.4!``"+,%EJ`>B]`0``4.C5`0``6?\P_U8(65G_-32@0`#H+@(``.B?`0``
M4.@=`@``68DX6>B0`0``4.@(`@``@`@"Z((!``!0Z/H!``"`"`&+10B#P`6)
M??R)1?A9WVWX6=P=`$1``-_@GG8+:.Q#0`#H=P$``%F+10B-!(44````4.BZ
M`0``6:-`I$``BTT,:@&+"8D(H4"D0`#'0`3H0T``H4"D0`#'0`@@1$``H4"D
M0`#'!3RD0``#````QT`,Y$-``/\%/*1``%@Y10A^'HL-/*1``(M5#(LU0*1`
M``/(BQ2"0(E4COP[10A\XJ$\I$``BTT(`\&+#4"D0`!7B7R!_*$\I$``BTT(
M_S5`I$``C40(_U!HRCA``/\U-*!``.@5`0``B_"#Q!0[]W4._S4TH$``Z/L`
M``!9B_#_-32@0`#HYP```,<$)%!"0`#H5MG__X7`674DH3B@0``[QW44:)A!
M0`#H/MG__SO'6:,XH$``=`=0Z'?[__]9_S4TH$``Z*$```!9_Q780$``B\9?
M7LG#Z"\```!0Z"O7__]9N)!"0`!J`%!0:((T0`!H"$1``.@0````4.BF````
M@\08P_\E'$%``/\E&$%``/\E%$%``/\E$$%``/\E#$%``/\E"$%``/\E!$%`
M`/\E`$%``/\E_$!``/\E^$!``/\E]$!``/\E\$!``/\E[$!``/\EZ$!``/\E
MY$!``/\EX$!``/\EW$!``/\EU$!``/\ET$!``/\ES$!``/\ER$!``/\EQ$!`
M`/\EP$!``/\EO$!``/\EN$!``/\EM$!``/\EL$!``/\EJ$!``/\ED$!``/\E
MB$!``,S,S,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(B\2%
M`8OABPB+0`10P\S_)6!`0`#_)5Q`0`#,S,S,58OL:O]HR)1``&@@.T``9*$`
M````4&2))0````"#["!35E>)9>B#9?P`:@'_%5A`0`!9@PU8I$``_X,-7*1`
M`/__%1A`0`"+#52D0`")"/\5'$!``(L-4*1``(D(H2!`0`"+`*-@I$``Z,``
M``"#/3"@0```=0QH'A!``/\5)$!``%GHE````&@,H$``:`B@0`#H?P```*%,
MI$``B478C4784/\U2*1``(U%X%"-1=10C47D4/\5+$!``&@$H$``:`"@0`#H
M3````/\5,$!``(M-X(D(_W7@_W74_W7DZ";\__^#Q#")1=Q0_Q4T0$``BT7L
MBPB+"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H```#
M`&@```$`Z`L```!96</#S/\EF$!``/\EG$!`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````,Z8````````B)@``)Z8``"LF````````&R:``!<F@``3)H``#B:```L
MF@``')H```R:```$F@``]ID``.Z9``#6F0``S)D``+Z9``"RF0``J)D``)J9
M``!ZF@``AID``'R9``!LF0``8)D``%:9``!,F0``0ID``#B9```NF0``'ID`
M`!29```*F0```)D``/:8``#LF```C)H``*":``"0F0```````&B8``!6F```
M0)@``#*8```@F````)@``.B7``#2EP``Q)<``+B7``"HEP``G)<``(J7``!V
MEP``9)<``%27``!`EP``,)<``""7```2EP``_I8``.Z6``#6E@``Q)8``+26
M``"DE@``D)8``'Z6``!JE@``7)8`````````````````````````````\<NW
M1@`````"````/0``````````T```.P```%P```!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`<&5R;'AS:2YC````)7,E<R5S```N````4$%27U!23T=.
M04U%`````%!!4E]414U0`````#$```!005)?0TQ%04X]``!#3$5!3@```%!!
M4E]'3$]"04Q?0TQ%04X`````4$%27T=,3T)!3%]414U0`%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]$14)51P````!005)?
M05)'5E\P``!005)?05)'0P````!005)?0T%#2$4```!005)?1$5"54<```!0
M05)?0TQ%04X```!005)?4U!!5TY%1`!005)?24Y)5$E!3$E:140`7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````$193$1?3$E"4D%2
M65]0051(````4$%42`````!,24)205)97U!!5$@`````3$E"4$%42`!,1%],
M24)205)97U!!5$@`)7,E<W1E;7`M)74E<P```"4P,G@`````)7,E<V-A8VAE
M+25S)7,``"5S)7,E<R5S`````'!A<BT`````4UE35$5-``!54T523D%-10``
M``!54T52`````%1-4`!414U0`````%1%35!$25(`5$U01$E2```O=&UP````
M`$,Z7%1%35``7"XN`%PN```E<P``)7-<)7,````E<UPJ+BH``"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("T@86)O<G1I;F<@=VET:"`E:2X*````,````'!E<FPN97AE`````!@`
M``!!4D=6`````"TM```M90``<&%N:6,Z(&UE;6]R>2!W<F%P`````(#____/
M04EN=&5R;F%L<SHZ4$%2.CI"3T]4`````",A+W5S<B]B:6XO<&5R;`H*979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@
M7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY
M(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC
M;&EN92`Q-3D*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!U;FQI;FL@0'1M
M<&9I;&4["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`D<&%R7W1E;7`@/7X@
M<WM;7EQ<+UTJ6UQ<+UT_)'U[?3L*("`@(')M9&ER("1P87)?=&5M<#L*?2!]
M"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I
M;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D
M14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%2
M7T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E
M14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?
M+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@
M9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG
M(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S
M=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S
M('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y
M<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&
M2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*
M"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?
M1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP
M;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A
M8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0[
M"B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@
M("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@
M("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@
M("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT
M+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T
M("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@
M("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO
M=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]
M("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@
M;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68[
M"B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@
M("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F
M=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)
M3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@
M("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@
M("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@
M("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME
M>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L
M97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@
M('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D
M;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@
M("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE
M+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL
M($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM[
M"@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@
M("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*
M("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F
M<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@
M<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO
M9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@
M("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S
M('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P
M<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R
M(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@
M('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@
M("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@
M("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["B`@("!W:&EL92`H0$%21U8I
M('L*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH
M+BHI+R!O<B!L87-T.PH*("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@
M("`@("`@('5N<VAI9G0@0$E.0RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@
M("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@
M("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@
M("`@("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?
M;F%M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*
M("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@
M("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN
M:71?:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"GT*"B,@6%A8
M("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T
M(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H*("`@(&UY("1P87(@
M/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE
M9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@
M("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@
M("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@
M("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*
M("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@
M("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A
M.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?
M<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P
M.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO
M861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X
M=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D
M,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F
M:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*
M"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N
M9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN
M8R@I.PH@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`
M:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET
M92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@:68@
M*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[7%Q]>R]]9R!F;W(@0&EN
M8R!]"@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N
M.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@
M("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T
M<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@
M("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@
M1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@
M("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T
M(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S
M<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H
M)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*
M("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S
M('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F
M:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@
M("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2
M(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A
M9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@
M>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@
M(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@
M("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;
M7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@
M("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("`D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@(&]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H
M97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S
M<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@
M("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA
M;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@
M("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I
M<F4@1FEL93HZ4&%T:#L*("`@(`H)1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E
M<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER
M92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A
M<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@
M("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N
M=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z
M.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF
M:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&
M:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@
M07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@5VEN
M,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["GT*"B,@
M5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M
M:W1M<&1I<BYC"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("@D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@
M(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@
M("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X
M="!U;FQE<W,@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@
M("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@
M(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@
M("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@
M("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E
M<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P
M871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD
M:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@
M("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@
M("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@
M("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@
M("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R
M:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*
M("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R
M;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C
M;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@
M("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L
M("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F
M:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE
M("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64[
M"B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL
M96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D[
M"B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@IS=6(@7W-E=%]P<F]G
M;F%M92!["B`@("!I9B`H)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@
M)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@
M(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?
M9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@
M=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z("1%3E9[4%=$?3L*("`@
M("1P=V0@/2!@<'=D8"!I9B`A9&5F:6YE9"`D<'=D.PH@("`@8VAO;7`H)'!W
M9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*
M("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@
M("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@
M*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@
M(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@
M("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@
M("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@
M:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L
M;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B
M0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O
M;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U
M=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S
M("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#DT-`H*
M7U]%3D1?7PH``'!A<BYP;```_____^`Z0`#T.D``X)4`````````````?)@`
M`*A```!`E0````````````#`F```"$```#B5`````````````-Z8````0```
M4)4`````````````XID``!A``````````````````````````````,Z8````
M````B)@``)Z8``"LF````````&R:``!<F@``3)H``#B:```LF@``')H```R:
M```$F@``]ID``.Z9``#6F0``S)D``+Z9``"RF0``J)D``)J9``!ZF@``AID`
M`'R9``!LF0``8)D``%:9``!,F0``0ID``#B9```NF0``'ID``!29```*F0``
M`)D``/:8``#LF```C)H``*":``"0F0```````&B8``!6F```0)@``#*8```@
MF````)@``.B7``#2EP``Q)<``+B7``"HEP``G)<``(J7``!VEP``9)<``%27
M``!`EP``,)<``""7```2EP``_I8``.Z6``#6E@``Q)8``+26``"DE@``D)8`
M`'Z6``!JE@``7)8```````#A`U!E<FQ?;F5W6%,````#4&5R;%]G971?8V]N
M=&5X=```'`5B;V]T7T1Y;F%,;V%D97(`9P)097)L7U1S=&%T8G5F7W!T<@"W
M`%!E<FQ?24Q)3U]P='(`N@!097)L7TE-96U?<'1R`+X`4&5R;%])4')O8U]P
M='(``,8"4&5R;%]C<F]A:U]N;V-O;G1E>'0``+4`4&5R;%])1&ER7W!T<@#6
M`%!E<FQ?26-O;7!C=E]P='(``)0#4&5R;%]M9U]S970`N01097)L7W-V7W-E
M='!V`(("4&5R;%]A=E]S:&EF=`!J!%!E<FQ?<W9?,G!V7V9L86=S`'L"4&5R
M;%]A=E]F971C:``B`U!E<FQ?9W9?9F5T8VAP=@!K`E!E<FQ?5'1A:6YT961?
M<'1R`!D%4&5R;%]W:6XS,E]T97)M`"<%<&5R;%]F<F5E`"8%<&5R;%]D97-T
M<G5C=``J!7!E<FQ?<G5N```I!7!E<FQ?<&%R<V4``!\$4&5R;%]S869E<WES
M;6%L;&]C``#W`%!E<FQ?265X:71?9FQA9W-?<'1R``!B`5!E<FQ?27!E<FQ?
M9&5S=')U8W1?;&5V96Q?<'1R`"4%<&5R;%]C;VYS=')U8W0``!\%<&5R;%]A
M;&QO8P``F`!097)L7T=D;U]U;F1U;7!?<'1R`!@%4&5R;%]W:6XS,E]I;FET
M`.(#4&5R;%]N97=84U]F;&%G<P``<&5R;#4X+F1L;```=0%'971-;V1U;&5&
M:6QE3F%M94$``.\`1G)E94QI8G)A<GD`=P%'971-;V1U;&5(86YD;&5!``!+
M15).14PS,BYD;&P``",!1V5T57-E<DYA;65!``!!1%9!4$DS,BYD;&P``+("
M<W!R:6YT9@"X`G-T<F-M<```QP)S=')T;VL``+X"<W1R;&5N``#%`G-T<G-T
M<@``;0!?7W!?7V5N=FER;VX``)@";65M;6]V90#!`G-T<FYC<'D`P`)S=')N
M8VUP`((!7VUK9&ER``".`5]P8W1Y<&4`%0%?:7-C='EP90``80!?7VUB7V-U
M<E]M87@``)<";65M8W!Y``"9`FUE;7-E=```F0%?<FUD:7(``-\`7V9I;F1C
M;&]S90``W0%?=6YL:6YK`.(`7V9I;F1N97AT`.``7V9I;F1F:7)S=```OP%?
M<W1R9'5P`,4!7W-T<FYI8VUP`$U35D-25"YD;&P``-,`7V5X:70`2`!?6&-P
M=$9I;'1E<@!)`F5X:70``&0`7U]P7U]?:6YI=&5N=@!8`%]?9V5T;6%I;F%R
M9W,`#P%?:6YI='1E<FT`@P!?7W-E='5S97)M871H97)R``"=`%]A9&IU<W1?
M9F1I=@``:@!?7W!?7V-O;6UO9&4``&\`7U]P7U]F;6]D90``@0!?7W-E=%]A
M<'!?='EP90``R@!?97AC97!T7VAA;F1L97(S``"W`%]C;VYT<F]L9G``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!004``3$%``/_____`E$``GE``
M``````````````````$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````,``P```"@``(`.````2```@!``
M``!@``"````````````````````"``$```!X``"``@```)```(``````````
M``````````$`90```*@``(````````````````````$``0```,```(``````
M``````````````$``````-@```````````````````````$``````.@`````
M``````````````````$``````/@```````````````````````$```````@!
M``"8LP``:`4``````````````+D``*@(`````````````*C!```B````````
M```````@L0``=`(```````````````````````!T`C0```!6`%,`7P!6`$4`
M4@!3`$D`3P!.`%\`20!.`$8`3P``````O03O_@```0``````````````````
M````/P````$````$``0``0```````````````````-0!```!`%,`=`!R`&D`
M;@!G`$8`:0!L`&4`20!N`&8`;P```+`!```!`#``-``P`#``,``T`&(`,```
M`!@````!`$,`;P!M`&T`90!N`'0`<P```"`````!`$,`;P!M`'``80!N`'D`
M3@!A`&T`90``````*`````$`1@!I`&P`90!$`&4`<P!C`'(`:0!P`'0`:0!O
M`&X``````"`````!`$8`:0!L`&4`5@!E`'(`<P!I`&\`;@``````(`````$`
M20!N`'0`90!R`&X`80!L`$X`80!M`&4````D`````0!,`&4`9P!A`&P`0P!O
M`'``>0!R`&D`9P!H`'0````H`````0!,`&4`9P!A`&P`5`!R`&$`9`!E`&T`
M80!R`&L`<P``````*`````$`3P!R`&D`9P!I`&X`80!L`$8`:0!L`&4`;@!A
M`&T`90```"`````!`%``<@!I`'8`80!T`&4`0@!U`&D`;`!D````(`````$`
M4`!R`&\`9`!U`&,`=`!.`&$`;0!E```````D`````0!0`'(`;P!D`'4`8P!T
M`%8`90!R`',`:0!O`&X````@`````0!3`'``90!C`&D`80!L`$(`=0!I`&P`
M9````$0````!`%8`80!R`$8`:0!L`&4`20!N`&8`;P``````)``$````5`!R
M`&$`;@!S`&P`80!T`&D`;P!N````````!+`$`````"@````0````(`````$`
M"`````````$```````````````$````!```&!@8`!`0$``("`@``````0D)"
M`)V=G0!N;FX`@8&!`+&QL0#___\`<W-S`)^?GP!86%@`LK*R`/W]_0!K:VL`
M_/S\`-?7UP`6%A8`VMK:`):6E@".CHX`1D9&`,O+RP`+"PL`H*"@`/[^_@#)
MR<D`P<'!``,#`P`1$1$`DY.3`+.SLP#N[NX`]/3T`./CXP#EY>4`HJ*B`+JZ
MN@"OKZ\`!P<'`'%Q<0"UM;4`]?7U`(F)B0"*BHH`-#0T`.CHZ``U-34`6EI:
M`+>WMP#8V-@`T-#0`!T='0`,#`P`CX^/`+Z^O@!M;6T`"0D)`)N;FP`O+R\`
MS<W-`-G9V0`9&1D`34U-`$1$1`!04%``/#P\`&1D9`#"PL(`,C(R``@("``-
M#0T`#P\/````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````4%!04%!04%!04%!04%!`0$!-4`C!4$Q0T%!1$4N
M`0$!`0$!`04!/!<7`0$3`0$!`0$!`0$5`0$F%0$!#P$!`0$!`0$!$P$1`04U
M`28!`0$!`0$!`2(2$#$/!0$@`0$!`0$!`0$0"B`B%14N(2X!`0$!`1\@(1`B
M$",C)28G`0$!`240$!`0$!`0$!`710$!`4$0$!`0$!`0$!`0$!<!`0$/$!`5
M$!`0$!`0$!`!`0$!$A`0$Q\0$!`0$!`'`0$!`2`0$!`!#Q`0$!`1`0$!`0$'
M(!`*`0$%$!`0,0$!`0$!`0$!`0$!`4$%#P$!`0$!`0$!`0$!`0$!`0$!`0$!
M`8`!``#``0``X`,``/`#``#P`P``\`,``.`#``#``0``@`$``(`!``"``P``
M@`,````'````!P``C@\``/\?```H````(````$`````!``@````````$````
M```````````!`````0````````$!`0`"`@(``P,#``0$!``%!04`!@8&``<'
M!P`("`@`"0D)``H*"@`+"PL`#`P,``T-#0`.#@X`#P\/`!`0$``1$1$`$A(2
M`!,3$P`4%!0`%145`!86%@`7%Q<`&!@8`!D9&0`:&AH`&QL;`!P<'``='1T`
M'AX>`!\?'P`@("``(2$A`"(B(@`C(R,`)"0D`"4E)0`F)B8`)R<G`"@H*``I
M*2D`*BHJ`"LK*P`L+"P`+2TM`"XN+@`O+R\`,#`P`#$Q,0`R,C(`,S,S`#0T
M-``U-34`-C8V`#<W-P`X.#@`.3DY`#HZ.@`[.SL`/#P\`#T]/0`^/CX`/S\_
M`$!`0`!!04$`0D)"`$-#0P!$1$0`145%`$9&1@!'1T<`2$A(`$E)20!*2DH`
M2TM+`$Q,3`!-34T`3DY.`$]/3P!04%``45%1`%)24@!34U,`5%14`%5550!6
M5E8`5U=7`%A86`!965D`6EI:`%M;6P!<7%P`75U=`%Y>7@!?7U\`8&!@`&%A
M80!B8F(`8V-C`&1D9`!E964`9F9F`&=G9P!H:&@`:6EI`&IJ:@!K:VL`;&QL
M`&UM;0!N;FX`;V]O`'!P<`!Q<7$`<G)R`'-S<P!T='0`=75U`'9V=@!W=W<`
M>'AX`'EY>0!Z>GH`>WM[`'Q\?`!]?7T`?GY^`']_?P"`@(``@8&!`(*"@@"#
M@X,`A(2$`(6%A0"&AH8`AX>'`(B(B`")B8D`BHJ*`(N+BP",C(P`C8V-`(Z.
MC@"/CX\`D)"0`)&1D0"2DI(`DY.3`)24E`"5E94`EI:6`)>7EP"8F)@`F9F9
M`)J:F@";FYL`G)R<`)V=G0">GIX`GY^?`*"@H`"AH:$`HJ*B`*.CHP"DI*0`
MI:6E`*:FI@"GIZ<`J*BH`*FIJ0"JJJH`JZNK`*RLK`"MK:T`KJZN`*^OKP"P
ML+``L;&Q`+*RL@"SL[,`M+2T`+6UM0"VMK8`M[>W`+BXN`"YN;D`NKJZ`+N[
MNP"\O+P`O;V]`+Z^O@"_O[\`P,#``,'!P0#"PL(`P\/#`,3$Q`#%Q<4`QL;&
M`,?'QP#(R,@`R<G)`,K*R@#+R\L`S,S,`,W-S0#.SLX`S\_/`-#0T`#1T=$`
MTM+2`-/3TP#4U-0`U=75`-;6U@#7U]<`V-C8`-G9V0#:VMH`V]O;`-S<W`#=
MW=T`WM[>`-_?WP#@X.``X>'A`.+BX@#CX^,`Y.3D`.7EY0#FYN8`Y^?G`.CH
MZ`#IZ>D`ZNKJ`.OKZP#L[.P`[>WM`.[N[@#O[^\`\/#P`/'Q\0#R\O(`\_/S
M`/3T]`#U]?4`]O;V`/?W]P#X^/@`^?GY`/KZ^@#[^_L`_/S\`/W]_0#^_OX`
M____`#0T-#P\/#P\/#P\/#P\/#P\/#P\/#P\/"P,!`0$!`0$7+34U-34U-34
MU-34W-34U-34U-34U-34M#11!`0$!`1DS.ST]/3\]/ST]/3\]/ST_/3\_/ST
M].S$-%%1!`0$!&3$Y.ST]/3T]/3T]/3T]/3T]/3T]/3L[+PT45%1!`0$9,3D
M[.SLY.SL[.3DY.3L[.3LY.SL[.SDO#1145%1!`1DO.3L[*R,K-3$E)2<E(R,
ME)24G)R<[-R\-%%145%1!&2\W.3LY,11E*QDY*1,-"Q<Q,Q1M-3DW+PT45%1
M45%19+S<Y.3LY.11A'3DC&RDG&R,O'2LU.3<O#0$!`0$!`1DO-SDY.SDY+Q1
MC-34C*S,=,S<I%'$Y-R\-`0$!`0$!&2\W.3DY.3DW(Q\G+1\A)QLS.2\=,3D
MW+0T!`0$!`0$7+S<W.3DY.34G*1<E(S,/)1DS+R,4=S4M#0$!`0$!`1DM-3<
MW-SDW(R,K"R\M,Q:Q&2<;)2DW-2T-`0$!`0$!%RTU-S<Y-S<=)343*3TC#S4
M=)1TG$S<S+0T!`0$!`0$9+34W-S<Y-QT4?1TA.S,9.1\;*2T;*34M#0$!`0$
M!`1DM,S<W,Q\C(2T_,S$_/2T_+QDS*R$4;RL-`0$!`0$!%RTS-3,C*3<W.S\
M_/S\_/3\[+3LK'R44:PT!`0$!`0$7*S,S&R<]/S\_/S\_/S\_/S\_/S$E(Q1
MK#0$!`0$!`1<K,2\?.3\_/S\_/S\_/S\_/S\_.S,K%&L-`0$!`0$!%RLM$S$
M_/S\[/3\_/S\_/S\_/S\]+Q1Q*PT!`0$!`0$7*RT3-3\_/2TW/S\_/S\_/S\
M_/S,4<S$I#0$!`0$!`1<K,2D4?S\_+2<]/S\_/S\_/S\])11S,2D+`0$!`0$
M!%RDI%&$[/S\S&2T[/S\_/S\_/S4;*S,O*0T!`0$!`0$7*1D=+ST_/S$482<
MY/S\_/S\Y(Q1S,S$I#0$!`0$!`1<I&R,Y/3\_)Q1S%&4[/S\_/R\=,S,Q+R<
M+`0$!`0$!%RDK&1<9*2D4:S,Q'24Y/3\Y%&\S,S$O)PT!`0$!`0$7*2TO+R,
M45'$Q,S,K%%\?)1L?+S,Q,2\G"P$!`0$!`1<G+S$Q,3$Q,3$Q,3$Q%%145&\
MQ,3$Q+2<-`0$!`0$!%2<M,3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,2\M)PL!`0$!`0$
M5)R\Q,2\O+R\O+R\O+R\O+R\O+R\O+RTG"P$!`0$!`1<G+3$O+2TM+2TM+2T
MM+2TM+2TM+2TM*R<+`0$!`0$!%2$E)R<E)24E)24E)24E)24E)24E)24E(0D
M!`0$!`0$1%1<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<5#0$!`0$!`0````_````
M'P````\````'`````P````$`````````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\````_````/P```#\`
M```_````/P```#\````_````/P```#\````_````/P```0`"`!`0```!``@`
M:`4```$`("````$`"`"H"````@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$Y",3``````\<NW1@$```!#.EQ097)L7&)U:6QD7%!!
=4BU086-K97(M,"XY-S9<;7EL9')<<&%R+G!D8@``
